-- Grab local references to global variables. We are trading RAM to decrease CPU usage and hopefully increase FPS
local C_Map = C_Map
local LibStub = LibStub
local UnitClassBase = UnitClassBase
local UnitFactionGroup = UnitFactionGroup

------------------- Get addon reference --------------------
---@class RepByZone: AceAddon, AceEvent-3.0, AceConsole-3.0
local RepByZone = LibStub("AceAddon-3.0"):GetAddon("RepByZone")

local H = UnitFactionGroup("player") == "Horde"
local A = UnitFactionGroup("player") == "Alliance"
local playerClass = UnitClassBase("player")

function RepByZone:ZoneAndFactionList()
    -- [UImapID] = factionID
    -- If an UImapID is not listed, that zone has no associated factionID
    -- see https://wow.gamepedia.com/UiMapID or https://wago.tools/db2/UiMap for the list of UImapIDs
    -- see https://wow.gamepedia.com/FactionID for the list of factionIDs

    local zonesAndFactions = {
        --------- Vanilla ----------
        [1]         = 46,       -- Durotar/Orgrimmar
        [3]         = 72,       -- Tiragarde Keep/Stormwind
        [4]         = 72,       -- Tiragarde Keep (Great Hall)/Stormwind
        [7]         = 81,       -- Mulgore/Thunder Bluff
        [10]        = A and 470 or H and 76, -- Northern Barrens/Ratchet or Orgrimmar
        [14]        = A and 509 or H and 510, -- Arathi Highlands/The League of Arathor or The Defilers
        [15]        = A and 47 or H and 76, -- Badlands/Ironforge or Orgrimmar
        [17]        = A and 72 or H and 76, -- Blasted Lands/Stormwind or Orgrimmar
        [18]        = 68,       -- Tirisfal Glades/Undercity
        [21]        = A and 1134 or H and 68, -- Silverpine Forest/Gilneas or Undercity
        [22]        = 1106,     -- Western Plaguelands/Argent Crusade
        [23]        = 1106,     -- Eastern Plaguelands/Argent Crusade
        [25]        = 68,       -- Hillsbrad Foothills/Undercity
        [26]        = A and 1174 or H and 530, -- Hinterlands/Wildhammer Clan or Darkspear Trolls
        [27]        = 47,       -- Dun Morogh/Ironforge
        [30]        = 54,       -- New Tinkertown/Gnomeregan
        [32]        = 59,       -- Searing Gorge/Thorium Brotherhood
        [36]        = A and 72 or H and 76, -- Burning Steppes/Stormwind or Orgrimmar
        [37]        = 72,       -- Elwynn Forest/Stormwind
        [41]        = 1090,     -- Dalaran Crater/Kirin Tor
        [42]        = 967,      -- Deadwind Pass/The Violet Eye
        [47]        = A and 72 or H and 68, -- Duskwood/Stormwind or Undercity
        [48]        = 47,       -- Loch Modan/Ironforge
        [49]        = 72,       -- Redridge Mountains/Stormwind
        [50]        = A and 72 or H and 76, -- Northern Stranglethorn/Stormwind or Orgrimmar
        [51]        = 76,       -- Swamp of Sorrows/Orgimmar
        [52]        = 72,       -- Westfall/Stormwind
        [56]        = 47,       -- Wetlands/Ironforge
        [57]        = 69,       -- Teldrassil/Darnassus
        [62]        = 69,       -- Darkshore/Darnassus
        [63]        = A and 69 or H and 1085, -- Ashenvale/Darnassus or Warsong Offensive
        [64]        = A and 54 or H and 1133, -- Thousand Needles/Gnomeregan or Bilgewater Cartel
        [65]        = A and 69 or H and 81, -- Stonetalon Mountains/Darnassus or Thunder Bluff
        [66]        = 609,      -- Desolace/Cenarion Circle
        [69]        = A and 69 or H and 81, -- Feralas/Darnassus or Thunder Bluff
        [70]        = A and 72 or H and 76, -- Dustwallow Marsh/Stormwind or Orgrimmar
        [71]        = 369,      -- Tanaris/Gadgetzan
        [74]        = 989,      -- Timeless Tunnel/Keepers of Time
        [75]        = 989,      -- Caverns of Time/Keepers of Time
        [76]        = 1133,     -- Azshara/Bilgewater Cartel
        [77]        = A and 69 or H and 1133, -- Felwood/Darnassus or Bilgewater Cartel
        [80]        = 609,      -- Moonglade/Cenarion Circle
        [81]        = 609,      -- Silithus/Cenarion Circle
        [83]        = 577,      -- Winterspring/Everlook
        [84]        = 72,       -- Stormwind City/Stormwind
        [85]        = 76,       -- Orgrimmar/Orgrimmar
        [87]        = 47,       -- Ironforge/Ironforge
        [88]        = 81,       -- Thunder Bluff/Thunder Bluff
        [89]        = 69,       -- Darnassus/Darnassus
        [90]        = 68,       -- Undercity/Undercity

        --------- TBC ---------
        [94]        = 911,      -- Eversong Woods/Silvermoon City
        [95]        = 922,      -- Ghostlands/Tranquillien
        [97]        = 930,      -- Azuremyst Isle/Exodar
        [100]       = A and 946 or H and 947, -- Hellfire Peninsula/Honor Hold or Thrallmar
        [102]       = 942,      -- Zangarmarsh/Cenarion Expedition
        [103]       = 930,      -- The Exodar/Exodar
        [104]       = 1012,     -- Shadowmoon Valley/Ashtongue Deathsworn
        [106]       = 930,      -- Bloodmyst Isle/Exodar
        [107]       = A and 978 or H and 941, -- Nagrand/Kurenai or The Mag'har
        [108]       = 1011,     -- Terokkar Forest/Lower City
        [109]       = 933,      -- Netherstorm/The Consortium
        [110]       = 911,      -- Silvermoon City/Silvermoon City
        [111]       = 935,      -- Shattrath City/The Sha'tar
        [122]       = 1077,     -- Isle of Quel'Danas/Shattered Sun Offensive

        --------- WotLK ---------
        [114]       = A and 1050 or H and 1085, -- Borean Tundra/Valiance Expedition or Warsong Offensive
        [115]       = 1091,     -- Dragonblight/The Wyrmrest Accord
        [116]       = A and 1050 or H and 1085, -- Grizzly Hills/Valiance Expedition or Warsong Offensive
        [117]       = A and 1050 or H and 1067, -- Howling Fjord/Valiance Expedition or The Hand of Vengeance
        [118]       = 1098,     -- Icecrown/Knights of the Ebon Blade
        [119]       = self.sholazarRepID, -- See Core-Retail.lua's CheckSholazarBasin()
        [120]       = 1119,     -- The Storm Peaks/The Sons of Hodir
        [121]       = 1106,     -- Zul'Drak/Argent Crusade
        [123]       = A and 1050 or H and 1052, -- Wintergrasp/Valiance Expedition or Horde Expedition
        [124]       = 1098,     -- Plaguelands: The Scarlet Enclave (DK starting zone)/Knights of the Ebon Blade
        [125]       = 1090,     -- Dalaran City/Kirin Tor
        [126]       = 1090,     -- Dalaran City (The Underbelly)/Kirin Tor
        [127]       = 1090,     -- Crystalsong Forest/Kirin Tor
        [170]       = 1106,     -- Hrothgar's Landing/Argent Crusade
        [1360]      = 1098,     -- Icecrown Citadel (The Frozen Throne)/Knights of the Ebon Blade

        --------- Cataclysm ---------
        [174]       = 1133,     -- The Lost Isles/Bilgewater Cartel
        [179]       = 1134,     -- Gilneas/Gilneas
        [194]       = 1133,     -- Kezan/Bilgewater Cartel
        [198]       = 1158,     -- Mount Hyjal/Guardians of Hyjal
        [199]       = A and 72 or H and 76, -- Southern Barrens/Stormwind or Orgrimmar
        [201]       = 1135,     -- Kelp'thar Forest/The Earthen Ring
        [202]       = 1134,     -- Gilneas City/Gilneas
        [203]       = 1135,     -- Vashj'ir/The Earthen Ring
        [204]       = 1135,     -- Abyssal Depths/The Earthen Ring
        [205]       = 1135,     -- Shimmering Expanse/The Earthen Ring
        [207]       = 1135,     -- Deephom/The Earthen Ring
        [210]       = A and 72 or H and 76, -- The Cape of Stranglethorn/Stormwind or Orgrimmar
        [217]       = A and 1134 or H and 68, -- Ruins of Gilneas/Gilneas or Undercity
        [218]       = 1134,     -- Ruins of Gilneas City/Gilneas
        [224]       = A and 72 or H and 76, -- Stranglethorn Vale/Stormwind or Orgrimmar
        [241]       = A and 1174 or H and 1172, -- Twilight Highlands/Wildhammer Clan or Dragonmaw Clan
        [244]       = A and 1177 or H and 1178, -- Tol Barad/Baradin's Warders or Hellscream's Reach
        [245]       = A and 1177 or H and 1178, -- Tol Barad Peninsula/Baradin's Warders or Hellscream's Reach
        [249]       = 1173,     -- Uldum/Ramkahen
        [276]       = 1135,     -- The Maelstrom/The Earthen Ring
        [738]       = 1204,     -- Firelands/Avengers of Hyjal
    }
    return zonesAndFactions
end

function RepByZone:SubZonesAndFactionsList()
    local subZonesAndFactions = {
		-- [C_Map.GetAreaInfo(areaID)]  = factionID
        -- see https://wow.tools/dbc/?dbc=areatable&build=10.0.5.47660#page=1 or https://wago.tools/db2/AreaTable?page=1

        [C_Map.GetAreaInfo(35)]         = 21,       -- Booty Bay/Booty Bay
        [C_Map.GetAreaInfo(36)]         = A and 730 or H and 729, -- Alterac Mountains/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(43)]         = 87,       -- Wild Shore/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(100)]        = 47,       -- Nesingwary's Expedition/Ironforge
        [C_Map.GetAreaInfo(133)]        = 54,       -- New Tinkertown/Gnomeregan
		[C_Map.GetAreaInfo(150)]        = 72,       -- Menethil Harbor/Stormwind
        [C_Map.GetAreaInfo(152)]        = 1106,     -- The Bulwark/Argent Crusade
        [C_Map.GetAreaInfo(193)]        = A and 72 or H and 68, -- Ruins of Andorhal/Stormwind or Undercity
        [C_Map.GetAreaInfo(196)]        = 72,       -- Uthor's Tomb/Stormwind
        [C_Map.GetAreaInfo(197)]        = 72,       -- Sorrow Hill/Stormwind
        [C_Map.GetAreaInfo(199)]        = 72,       -- Felstone Field/Stormwind
        [C_Map.GetAreaInfo(201)]        = 68,       -- Gahrron's Withering/Undercity
        [C_Map.GetAreaInfo(202)]        = 68,       -- Writhing Haunt/Undercity
        [C_Map.GetAreaInfo(204)]        = 1134,     -- Pyrewood Village/Gilneas
        [C_Map.GetAreaInfo(233)]        = 1134,     -- Ambermill/Gilneas
        [C_Map.GetAreaInfo(250)]        = 59,       -- Ruins of Thaurissan
        [C_Map.GetAreaInfo(279)]        = 1090,     -- Dalaran Crater/Kirin Tor
        [C_Map.GetAreaInfo(280)]        = 349,      -- Strahnbrad/Ravenholdt
        [C_Map.GetAreaInfo(288)]        = 72,       -- Azurelode Mine/Stormwind
		[C_Map.GetAreaInfo(297)]        = 81,       -- Jaguero Isle/Thunder Bluff
		[C_Map.GetAreaInfo(299)]        = 72,       -- Menethil Bay/Stormwind
        [C_Map.GetAreaInfo(313)]        = 349,      -- Northfold Manor/Ravenholdt
        [C_Map.GetAreaInfo(315)]        = 72,       -- Dabyrie's Farmstead/Stormwind
        [C_Map.GetAreaInfo(317)]        = A and 1174 or H and 530, -- Witherbark Village/Wildhammer Clan or Darkspear Trolls
        [C_Map.GetAreaInfo(320)]        = 72,       -- Refuge Pointe/Stormwind
        [C_Map.GetAreaInfo(321)]        = 68,       -- Hammerfall/Undercity
        [C_Map.GetAreaInfo(324)]        = 349,      -- Stromgarde Keep/Ravenholdt
        [C_Map.GetAreaInfo(327)]        = 21,       -- Faldir's Cove/Booty Bay
        [C_Map.GetAreaInfo(328)]        = 21,       -- The Drowned Reef/Booty Bay
        [C_Map.GetAreaInfo(330)]        = 47,       -- Thandol Span/Ironforge
        [C_Map.GetAreaInfo(350)]        = 69,       -- Quel'Danil Lodge/Darnassus
		[C_Map.GetAreaInfo(359)]        = A and 47 or H and 81, -- Bael Modan/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(367)]        = 530,      -- Sen'jen Village/Darkspear Trolls
        [C_Map.GetAreaInfo(368)]        = 530,      -- Echo Isles/Darkspear Trolls
        [C_Map.GetAreaInfo(392)]        = 470,      -- Ratchet/Ratchet
        [C_Map.GetAreaInfo(393)]        = 530,      -- Darkspear Strand/Darkspear Trolls
        [C_Map.GetAreaInfo(401)]        = H and playerClass == "SHAMAN" and 1135, -- The Tidus Stair/The Earthen Ring (only for Horde shamans)
        [C_Map.GetAreaInfo(439)]        = A and 54 or H and 76, -- The Shimmering Flats/Gnomeregan or Orgrimmar
        [C_Map.GetAreaInfo(484)]        = A and 69 or H and 81, -- Freewind Post/Darnassus or Thunder Bluff
        [C_Map.GetAreaInfo(501)]        = 369,      -- Beezil's Wreck/Gadgetzan
        [C_Map.GetAreaInfo(517)]        = 1358,     -- Tidefury Cove/Nat Pagle
		[C_Map.GetAreaInfo(596)]        = 470,      -- Kodo Graveyard/Ratchet
        [C_Map.GetAreaInfo(603)]        = 69,       -- Sargeron/Darnassus
        [C_Map.GetAreaInfo(604)]        = 93,       -- Magram Village (Shok'Thokar)/Magram Clan Centaur
        [C_Map.GetAreaInfo(606)]        = 92,       -- Gelkis Village/Gelkis Clan Centaur
        [C_Map.GetAreaInfo(608)]        = 69,       -- Nijel's Point/Darnassus
        [C_Map.GetAreaInfo(609)]        = 93,       -- Kolkar Village/Magram Clan Centaur
        [C_Map.GetAreaInfo(657)]        = 930,      -- The Harborage/Exodar
        [C_Map.GetAreaInfo(702)]        = 69,       -- Rut'theran Village/Darnassus
        [C_Map.GetAreaInfo(721)]        = 54,       -- Gnomeregan/Gnomeregan
        [C_Map.GetAreaInfo(813)]        = 1106,     -- The Bulwark/Argent Crusade
        [C_Map.GetAreaInfo(880)]        = 1174,     -- Thandol Span (Arathi Highlands)/Wildhammer Clan
        [C_Map.GetAreaInfo(881)]        = 47,       -- Thandol Span (Wetlands)/Ironforge
        [C_Map.GetAreaInfo(896)]        = A and 730 or H and 729, -- Purgation Isle/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(978)]        = A and 1174 or H and 530, -- Zul'Farrak/Wildhammer Clan or Darkspear Trolls
        [C_Map.GetAreaInfo(987)]        = 1133,     -- Land's End Beach/Bilgewater Cartel
        [C_Map.GetAreaInfo(989)]        = 1173,     -- Ruins of Uldum/Ramkahen
        [C_Map.GetAreaInfo(990)]        = 1173,     -- Valley of the Watchers/Ramkahen
        [C_Map.GetAreaInfo(1016)]       = 69,       -- Direforge Hill/Darnassus
        [C_Map.GetAreaInfo(1025)]       = 69,       -- The Green Belt/Darnassus
        [C_Map.GetAreaInfo(1057)]       = A and 47 or H and 68, -- Thoradin's Wall (Hillsbrad Foothills)/Ironforge or Undercity
        [C_Map.GetAreaInfo(1216)]       = 579,      -- Timbermaw Hold/Timbermaw Hold
        [C_Map.GetAreaInfo(1220)]       = 69,       -- Darnassian Base Camp/Darnassus
        [C_Map.GetAreaInfo(1336)]       = A and 54 or H and 1133, -- Lost Rigger Cove/Gnomeregan or Bilgewater Cartel
        [C_Map.GetAreaInfo(1446)]       = 59,       -- Thorium Point/Thorium Brotherhood
		[C_Map.GetAreaInfo(1658)]       = 609,      -- Cenarion Enclave/Cenarion Circle
        [C_Map.GetAreaInfo(1677)]       = A and 730 or H and 729, -- Gavin's Naze/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(1678)]       = 72,       -- Sofera's Naze/Stormwind
        [C_Map.GetAreaInfo(1679)]       = A and 730 or H and 729, -- Corrahn's Dagger/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(1680)]       = A and 730 or H and 729, -- The Headland/Stormpike Guard or Frostwolf Clan
		[C_Map.GetAreaInfo(1739)]       = 1133,     -- Hardwrench Hideaway/Bilgewater Cartel
        [C_Map.GetAreaInfo(1741)]       = 87,       -- Gurubashi Arena/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(1757)]       = 87,       -- The Crimson Veil/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(1758)]       = 87,       -- The Riptide/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(1759)]       = 87,       -- The Damsel's Luck/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(1761)]       = 579,      -- Deadwood Village/Timbermaw Hold
        [C_Map.GetAreaInfo(1762)]       = 579,      -- Felpaw Village/Timbermaw Hold
        [C_Map.GetAreaInfo(1769)]       = 579,      -- Timbermaw Hold/Timbermaw Hold
        [C_Map.GetAreaInfo(1778)]       = 369,      -- Sorrowmurk/Gadgetzan
        [C_Map.GetAreaInfo(1797)]       = 1133,     -- Stagalbog/Bilgewater Cartel
        [C_Map.GetAreaInfo(1837)]       = A and 1174 or H and 530, -- Witherbark Caverns/Wildhammer Clan or Darkspear Trolls
        [C_Map.GetAreaInfo(1857)]       = A and 47 or H and 68, -- Thoradin's Wall (Arathi Highlands)/Ironforge or Undercity
		[C_Map.GetAreaInfo(1858)]       = 1174,     -- Boulder'gor/Wildhammer Clan
        [C_Map.GetAreaInfo(1941)]       = 989,      -- Caverns of Time/Keepers of Time
        [C_Map.GetAreaInfo(1998)]       = 1134,     -- Talonbranch Glade/Gilneas
        [C_Map.GetAreaInfo(2079)]       = A and 54 or H and 68, -- Alcaz Island/Gnomeregan or Undercity
		[C_Map.GetAreaInfo(2097)]       = A and 69 or H and 81, -- Darkcloud Pinnacle/Darnassus or Thunder Bluff
		[C_Map.GetAreaInfo(2157)]       = A and 47 or H and 81, -- Bael'dun Keep/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(2177)]       = 87,       -- Battle Ring/Bloodsail Buccaneers
		[C_Map.GetAreaInfo(2240)]       = A and 54 or H and 1133, -- Mirage Raceway/Gnomeregan or Bilgewater Cartel
        [C_Map.GetAreaInfo(2241)]       = 589,      -- Frostsaber Rock/Wintersaber Trainers
        [C_Map.GetAreaInfo(2242)]       = 69,       -- The Hidden Grove/Darnassus
        [C_Map.GetAreaInfo(2243)]       = 579,      -- Timbermaw Post/Timbermaw Hold
        [C_Map.GetAreaInfo(2244)]       = 579,      -- Winterfall Village/Timbermaw Hold
        [C_Map.GetAreaInfo(2246)]       = 579,      -- Frostfire Hot Springs/Timbermaw Hold
        [C_Map.GetAreaInfo(2248)]       = 47,       -- Dun Mandarr/Ironforge
        [C_Map.GetAreaInfo(2253)]       = 69,       -- Starfall Village/Darnassus
        [C_Map.GetAreaInfo(2257)]       = 72,       -- Deeprun Tram/Stormwind
        [C_Map.GetAreaInfo(2276)]       = 69,       -- Quel'Lithien Lodge/Darnassus
        [C_Map.GetAreaInfo(2300)]       = 989,      -- Caverns of Time/Keepers of Time
        [C_Map.GetAreaInfo(2379)]       = 72,       -- Azurelode Mine/Stormwind
        [C_Map.GetAreaInfo(2404)]       = 69,       -- Tethris Aran/Darnassus
        [C_Map.GetAreaInfo(2406)]       = 69,       -- Ranazjar Isle/Darnassus
        [C_Map.GetAreaInfo(2407)]       = 470,      -- Kormek's Hut/Ratchet
        [C_Map.GetAreaInfo(2408)]       = 530,      -- Shadowprey Village/Darkspear Trolls
        [C_Map.GetAreaInfo(2539)]       = 530,      -- Malaka'jin/Darkspear Trolls
        [C_Map.GetAreaInfo(2597)]       = A and 730 or H and 729, -- Alterac Valley/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(2617)]       = 470,      -- Scrabblescrew's Camp/Ratchet
        [C_Map.GetAreaInfo(2738)]       = 69,       -- Southwind Village/Darnassus
        [C_Map.GetAreaInfo(2839)]       = A and 730 or H and 729, -- Alterac Valley/Stormpike Guard or Frostwolf Clan
        [C_Map.GetAreaInfo(2897)]       = 530,      -- Zoram'gar Outpost/Darkspear Trolls
        [C_Map.GetAreaInfo(3137)]       = 69,       -- Talrendis Point/Darnassus
		[C_Map.GetAreaInfo(3197)]       = 72,       -- Chillwind Camp/Stormwind
        [C_Map.GetAreaInfo(3319)]       = 890,      -- Silverwing Grove/Silverwing Sentinels
        [C_Map.GetAreaInfo(3426)]       = 69,       -- Staghelm Point/Darnassus
        [C_Map.GetAreaInfo(3427)]       = 47,       -- Bronzebeard Encampment/Ironforge
        [C_Map.GetAreaInfo(3486)]       = 349,      -- Ravenholdt Manor/Ravenholdt
        [C_Map.GetAreaInfo(4010)]       = 369,      -- Mudsprocket/Gadgetzan
        [C_Map.GetAreaInfo(4690)]       = 1135,     -- Thunder Peak/The Earthen Ring
        [C_Map.GetAreaInfo(4715)]       = 1133,     -- The Skunkworks/Bilgewater Cartel
        [C_Map.GetAreaInfo(4745)]       = 76,       -- Orgrimmar Rear Gate/Orgrimmar
        [C_Map.GetAreaInfo(4798)]       = 1068,     -- Thoargad's Camp/Explorer's League
        [C_Map.GetAreaInfo(4803)]       = 911,      -- Furien's Post/Silvermoon City
        [C_Map.GetAreaInfo(4882)]       = 369,      -- Marshal's Stand/Gadgetzan
        [C_Map.GetAreaInfo(4883)]       = 369,      -- Mossy Pile/Gadgetzan
        [C_Map.GetAreaInfo(4925)]       = 609,      -- Thunk's Abode/Cenarion Circle
        [C_Map.GetAreaInfo(4927)]       = 76,       -- The Fold/Orgimmar
        [C_Map.GetAreaInfo(4933)]       = 76,       -- Krom'gar Fortress/Orgimmar
        [C_Map.GetAreaInfo(4934)]       = 1133,     -- The Sludgewerks/Bilgewater Cartel
        [C_Map.GetAreaInfo(4940)]       = 1068,     -- Northwatch Expedition Base Camp/Explorer's League
        [C_Map.GetAreaInfo(5011)]       = 81,       -- Westreach Summit/Thunder Bluff
        [C_Map.GetAreaInfo(5028)]       = 87,       -- Southsea Holdfast/Bloodsail Buccaneers
        [C_Map.GetAreaInfo(5041)]       = A and 54 or H and 1133, -- Fizzle & Pozzik's Speedbarge/Gnomeregan or Bilgewater Cartel
        [C_Map.GetAreaInfo(5044)]       = 609,      -- The Tainted Forest/Cenarion Circle
        [C_Map.GetAreaInfo(5048)]       = A and 54 or H and 1133, -- Raceway Ruins/Gnomeregan or Bilgewater Cartel
        [C_Map.GetAreaInfo(5083)]       = 911,      -- Sunveil Excursion/Silvermoon City
        [C_Map.GetAreaInfo(5117)]       = 1133,     -- Nozzlepot's Outpost/Bilgewater Cartel
        [C_Map.GetAreaInfo(5121)]       = 68,       -- Galen's Fall/Undercity
        [C_Map.GetAreaInfo(5150)]       = 47,       -- Dwarven District/Ironforge
        [C_Map.GetAreaInfo(5169)]       = 530,      -- Valley of Spirits/Darkspear Trolls
        [C_Map.GetAreaInfo(5171)]       = 81,       -- Valley of Wisdom/Thunder Bluff
        [C_Map.GetAreaInfo(5305)]       = 69,       -- Greenwarden's Grove/Darnassus
        [C_Map.GetAreaInfo(5317)]       = 530,      -- Bambala/Darkspear Trolls
        [C_Map.GetAreaInfo(5367)]       = 942,      -- The Mender's Stead/Cenarion Circle
        [C_Map.GetAreaInfo(5388)]       = 911,      -- Dawnrise Expedition/Silvermoon City
        [C_Map.GetAreaInfo(5458)]       = 369,      -- Bogpaddle/Gadgetzan
        [C_Map.GetAreaInfo(5476)]       = 1134,     -- Pyrewood Chapel/Gilneas
        [C_Map.GetAreaInfo(5477)]       = 1134,     -- Pyrewood Inn/Gilneas
        [C_Map.GetAreaInfo(5478)]       = 1134,     -- Pyrewood Town Hall/Gilneas
        [C_Map.GetAreaInfo(5480)]       = 1134,     -- Gilneas Liberation Base Camp/Gilneas
        [C_Map.GetAreaInfo(5481)]       = 2159,     -- 7th Legion Base Camp/7th Legion
        [C_Map.GetAreaInfo(5495)]       = 54,       -- Gnomeregan/Gnomeregan
        [C_Map.GetAreaInfo(5496)]       = 369,      -- Fuselight/Gadgetzan
        [C_Map.GetAreaInfo(5497)]       = 369,      -- Fuselight-by-the-Sea/Gadgetzan
        [C_Map.GetAreaInfo(5524)]       = 911,      -- Bloodwatcher Point/Silvermoon City
        [C_Map.GetAreaInfo(5564)]       = 72,       -- Dragon's Mouth/Stormwind
        [C_Map.GetAreaInfo(5645)]       = 609,      -- Whisperwind Grove/Cenarion Circle
        [C_Map.GetAreaInfo(5649)]       = 609,      -- Wildheart Point/Cenarion Circle
        [C_Map.GetAreaInfo(5654)]       = 59,       -- Chiselgrip/Thorium Brotherhood
        [C_Map.GetAreaInfo(5675)]       = A and 69 or H and 81, -- Arikara's Needle/Darnassus or Thunder Bluff
        [C_Map.GetAreaInfo(5687)]       = 1134,     -- Darnassus: The Howling Oak/Gilneas
        [C_Map.GetAreaInfo(5705)]       = A and 47 or H and 530, -- Snowden Chalet/Ironforge or Darkspear Trolls
        [C_Map.GetAreaInfo(5706)]       = 369,      -- The Steam Pools/Gadgetzan

        --------- TBC ---------
        [C_Map.GetAreaInfo(3482)]       = 922,      -- The Dead Scar (Eversong Woods)/Tranquillien
        [C_Map.GetAreaInfo(3514)]       = 922,      -- The Dead Scar (Ghostlands)/Tranquillien
        [C_Map.GetAreaInfo(3530)]       = A and 930 or H and 911, -- Shadow Ridge/Exodar or Silvermoon City
        [C_Map.GetAreaInfo(3547)]       = 1077,     -- Throne of Kil'jaeden/Shattered Sun Offensive
        [C_Map.GetAreaInfo(3552)]       = 978,      -- Temple of Telhamat/Kurenai
        [C_Map.GetAreaInfo(3554)]       = 911,      -- Falcon Watch/Silvermoon City
        [C_Map.GetAreaInfo(3555)]       = 941,      -- Mag'har Post/The Mag'har
        [C_Map.GetAreaInfo(3569)]       = 69,       -- Tides' Hollow/Darnassus
        [C_Map.GetAreaInfo(3573)]       = 72,       -- Odesyus' Landing/Stormwind
        [C_Map.GetAreaInfo(3590)]       = 69,       -- Wrathscale Lair/Darnassus
        [C_Map.GetAreaInfo(3591)]       = 69,       -- Ruins of Loreth'Aran/Darnassus
        [C_Map.GetAreaInfo(3596)]       = A and playerClass == "SHAMAN" and 1135, -- The Hidden Reef/The Earthen Ring (only for Alliance shamans)
        [C_Map.GetAreaInfo(3598)]       = 69,       -- Wyrmscar Island/Darnassus
        [C_Map.GetAreaInfo(3615)]       = 1135,     -- Throne of the Elements/The Earthen Ring
        [C_Map.GetAreaInfo(3623)]       = 933,      -- Aeris Landing/The Consortium
        [C_Map.GetAreaInfo(3636)]       = 1135,     -- Elemental Plateau/The Earthen Ring
        [C_Map.GetAreaInfo(3673)]       = 47,       -- Nesingwary Safari/Ironforge
        [C_Map.GetAreaInfo(3628)]       = A and 930 or H and 911, -- Halaa/Exodar or Silvermoon City
        [C_Map.GetAreaInfo(3630)]       = 933,      -- Oshu'gun/The Consortium
        [C_Map.GetAreaInfo(3631)]       = 933,      -- Spirit Fields/The Consortium
        [C_Map.GetAreaInfo(3644)]       = 930,      -- Telredor/Exodar
        [C_Map.GetAreaInfo(3645)]       = 530,      -- Zabra'jin/Darkspear Trolls
        [C_Map.GetAreaInfo(3646)]       = 970,      -- Quagg Ridge/Sporeggar
        [C_Map.GetAreaInfo(3647)]       = 970,      -- The Spawning Glen/Sporeggar
        [C_Map.GetAreaInfo(3649)]       = 970,      -- Sporeggar/Sporeggar
        [C_Map.GetAreaInfo(3652)]       = 970,      -- Funggor Cavern/Sporeggar
        [C_Map.GetAreaInfo(3674)]       = 942,      -- Cenarion Thicket/Cenarion Expedition
        [C_Map.GetAreaInfo(3679)]       = 1031,     -- Skettis/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3680)]       = 1031,     -- Blackwind Valley/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3681)]       = 934,      -- Firewing Point/The Scryers
        [C_Map.GetAreaInfo(3683)]       = 941,      -- Stonebreaker Hold/The Mag'har
        [C_Map.GetAreaInfo(3684)]       = 69,       -- Allerian Stronghold/Darnassus
        [C_Map.GetAreaInfo(3690)]       = 1031,     -- Blackwind Lake/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3691)]       = 1031,     -- Lake Ere'Noru/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3718)]       = 530,      -- Swamprat Post/Darkspear Trolls
        [C_Map.GetAreaInfo(3719)]       = 941,      -- Bleeding Hollow Ruins/The Mag'har
        [C_Map.GetAreaInfo(3744)]       = 76,       -- Shadowmoon Village/Orgrimmar
        [C_Map.GetAreaInfo(3745)]       = 1174,     -- Wildhammer Stronghold/Wildhammer Clan
        [C_Map.GetAreaInfo(3754)]       = 932,      -- Altar of Sha'tar/The Aldor
        [C_Map.GetAreaInfo(3758)]       = 1015,     -- Netherwing Fields/Netherwing
        [C_Map.GetAreaInfo(3759)]       = 1015,     -- Netherwing Ledge/Netherwing
        [C_Map.GetAreaInfo(3766)]       = 978,      -- Orebor Harborage/Kurenai
        [C_Map.GetAreaInfo(3778)]       = 1068,     -- Draenethyst Mine/Explorer's League
        [C_Map.GetAreaInfo(3769)]       = 941,      -- Thunderlord Stronghold/The Mag'har
        [C_Map.GetAreaInfo(3771)]       = 69,       -- The Living Grove/Darnassus
        [C_Map.GetAreaInfo(3772)]       = 69,       -- Sylvanaar/Darnassus
        [C_Map.GetAreaInfo(3784)]       = 1031,     -- Forge Camp: Terror/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3785)]       = 1031,     -- Forge Camp: Wrath/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3786)]       = 1038,     -- Ogri'la/Ogri'la
        [C_Map.GetAreaInfo(3792)]       = 933,      -- Mana-Tombs/The Consortium
        [C_Map.GetAreaInfo(3801)]       = 941,      -- Mag'har Grounds/The Mag'har
        [C_Map.GetAreaInfo(3806)]       = 911,      -- Supply Caravan/Silvermoon City
        [C_Map.GetAreaInfo(3808)]       = 942,      -- Cenarion Post/Cenarion Expedition
        [C_Map.GetAreaInfo(3816)]       = 21,       -- Zeppelin Crash/Booty Bay
        [C_Map.GetAreaInfo(3828)]       = 942,      -- Ruuan Weald/Cenarion Expedition
        [C_Map.GetAreaInfo(3832)]       = 1038,     -- Vortex Summit/Ogri'la
        [C_Map.GetAreaInfo(3839)]       = 1011,     -- Abandoned Armory/Lower City
        [C_Map.GetAreaInfo(3842)]       = 935,      -- Tempest Keep (Netherstorm)/The Sha'tar
        [C_Map.GetAreaInfo(3864)]       = 1031,     -- Bash'ir Landing/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3896)]       = 932,      -- Aldor Rise/The Aldor
        [C_Map.GetAreaInfo(3898)]       = 934,      -- Scryer's Tier/The Scryers
        [C_Map.GetAreaInfo(3899)]       = 1011,     -- Lower City/Lower City
        [C_Map.GetAreaInfo(3901)]       = 69,       -- Allerian Post/Darnassus
        [C_Map.GetAreaInfo(3902)]       = 941,      -- Stonebreaker Camp/The Mag'har
        [C_Map.GetAreaInfo(3918)]       = 54,       -- Toshley's Station/Gnomeregan
        [C_Map.GetAreaInfo(3936)]       = 1174,     -- Deathforge Tower/Wildhammer Clan
        [C_Map.GetAreaInfo(3937)]       = 76,       -- Slag Watch/Orgrimmar
        [C_Map.GetAreaInfo(3938)]       = 934,      -- Sanctum of the Stars/The Scryers
        [C_Map.GetAreaInfo(3951)]       = 942,      -- Evergrove/Cenarion Expedition
        [C_Map.GetAreaInfo(3952)]       = 942,      -- Wyrmskull Bridge/Cenarion Expedition
        [C_Map.GetAreaInfo(3958)]       = 1031,     -- Sha'tari Base Camp/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3965)]       = 1015,     -- Netherwing Mines/Netherwing
        [C_Map.GetAreaInfo(3966)]       = 1015,     -- Dragonmaw Base Camp/Netherwing
        [C_Map.GetAreaInfo(3964)]       = 1031,     -- Skyguard Outpost/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3973)]       = 1031,     -- Blackwind Landing/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3974)]       = 1031,     -- Veil Harr'ik/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3975)]       = 1031,     -- Terokk's Rest/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3976)]       = 1031,     -- Veil Ala'rak/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3977)]       = 1031,     -- Upper Veil Shil'ak/Sha'tari Skyguard
        [C_Map.GetAreaInfo(3978)]       = 1031,     -- Lower Veil Shil'ak/Sha'tari Skyguard
        [C_Map.GetAreaInfo(5554)]       = 935,      -- The Mechanar Entrance/The Sha'tar
        [C_Map.GetAreaInfo(5555)]       = 935,      -- The Botanica Entrance/The Sha'tar
        [C_Map.GetAreaInfo(5556)]       = 935,      -- The Arcatraz Entrance/The Sha'tar

        --------- WotLK ---------
        [C_Map.GetAreaInfo(3987)]       = 1073,     -- The Isle of Spears/The Kalu'ak
        [C_Map.GetAreaInfo(3988)]       = 1073,     -- Kamagua/The Kalu'ak
        [C_Map.GetAreaInfo(3990)]       = 1073,     -- Scalawag Point/The Kalu'ak
        [C_Map.GetAreaInfo(3996)]       = 1068,     -- Baelgun's Excavation Site/Explorer's League
        [C_Map.GetAreaInfo(3997)]       = 1068,     -- Explorers' League Outpost/Explorers' League
        [C_Map.GetAreaInfo(3999)]       = 1068,     -- Steel Gate/Explorers' League
        [C_Map.GetAreaInfo(4018)]       = 1064,     -- Camp Winterhoof/The Taunka
        [C_Map.GetAreaInfo(4023)]       = 1090,     -- Amber Ledge/Kirin Tor
        [C_Map.GetAreaInfo(4024)]       = 1090,     -- Coldarra/Kirin Tor
        [C_Map.GetAreaInfo(4033)]       = 942,      -- Winterfin Village/Cenarion Expedition
        [C_Map.GetAreaInfo(4037)]       = 1064,     -- Taunka'le Village/The Taunka
        [C_Map.GetAreaInfo(4040)]       = 1073,     -- Njord's Breath Bay/The Kalu'ak
        [C_Map.GetAreaInfo(4041)]       = 1073,     -- Kaskala/The Kalu'ak
        [C_Map.GetAreaInfo(4097)]       = 942,      -- Winterfin Caverns/Cenarion Expedition
        [C_Map.GetAreaInfo(4099)]       = 942,      -- Winterfin Retreat/Cenarion Expedition
        [C_Map.GetAreaInfo(4113)]       = 1073,     -- Unu'pe/The Kalu'ak
        [C_Map.GetAreaInfo(4120)]       = 1090,     -- The Nexus/Kirin Tor
        [C_Map.GetAreaInfo(4121)]       = 1090,     -- Transitus Shield/Kirin Tor
        [C_Map.GetAreaInfo(4151)]       = 1064,     -- Westwind Refuge Camp/The Taunka
        [C_Map.GetAreaInfo(4152)]       = 1073,     -- Moa'ki Harbor/The Kalu'ak
        [C_Map.GetAreaInfo(4155)]       = 1073,     -- The Half Shell/The Kalu'ak
        [C_Map.GetAreaInfo(4158)]       = 1037,     -- Stars' Rest/Alliance Vanguard
        [C_Map.GetAreaInfo(4165)]       = 1052,     -- Agmar's Hammer/Horde Expedition
        [C_Map.GetAreaInfo(4169)]       = 1037,     -- Fordragon Hold/Alliance Vanguard
        [C_Map.GetAreaInfo(4170)]       = 1052,     -- Kor'kron Vanguard/Horde Expedition
        [C_Map.GetAreaInfo(4171)]       = A and 1037 or H and 1052, -- The Court of Skulls/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4172)]       = A and 1037 or H and 1052, -- Angrathar the Wrathgate/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4177)]       = 1037,     -- Wintergarde Keep/Alliance Vanguard
        [C_Map.GetAreaInfo(4178)]       = 1037,     -- Wintergarde Mine/Alliance Vanguarde
        [C_Map.GetAreaInfo(4186)]       = 1067,     -- Venomspite/The Hand of Vengeance
        [C_Map.GetAreaInfo(4188)]       = 1037,     -- The Carrion Fields/Alliance Vanguard
        [C_Map.GetAreaInfo(4189)]       = 942,      -- D.E.H.T.A Encampment/Cenarion Expedition
        [C_Map.GetAreaInfo(4190)]       = 1037,     -- Thorson's Post/Alliance Vanguard
        [C_Map.GetAreaInfo(4191)]       = 1106,     -- Light's Trust/Argent Crusade
        [C_Map.GetAreaInfo(4211)]       = 1064,     -- Camp Oneqwah/The Taunka
        [C_Map.GetAreaInfo(4224)]       = 1073,     -- The Briny Pinnacle/The Kalu'ak
        [C_Map.GetAreaInfo(4226)]       = 1073,     -- Iskaal/The Kalu'ak
        [C_Map.GetAreaInfo(4227)]       = 530,      -- Dragon's Fall/Darkspear Trolls
        [C_Map.GetAreaInfo(4233)]       = 1106,     -- Dawn's Reach/Argent Crusade
        [C_Map.GetAreaInfo(4234)]       = 1106,     -- Naxxramas/Argent Crusade
        [C_Map.GetAreaInfo(4243)]       = 1037,     -- Wintergarde Crypt/Alliance Vanguard
        [C_Map.GetAreaInfo(4246)]       = 1037,     -- Wintergarde Mausoleum/Alliance Vanguard
        [C_Map.GetAreaInfo(4253)]       = 2159,     -- 7th Legion Front/7th Legion
        [C_Map.GetAreaInfo(4256)]       = A and 1094 or H and 1124, -- Drak'mar Lake/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4261)]       = 68,       -- Ghostblade Point/Undercity
        [C_Map.GetAreaInfo(4281)]       = 1098,     -- Acherus: The Ebon Hold (Eastern Kingdoms)/Knights of the Ebon Blade
        [C_Map.GetAreaInfo(4284)]       = 47,       -- Nesingwary Base Camp/Ironforge
        [C_Map.GetAreaInfo(4286)]       = 1105,     -- The Bones of Nozronn/The Oracles
        [C_Map.GetAreaInfo(4287)]       = 1104,     -- Kartak's Hold/Frenzyheart Tribe
        [C_Map.GetAreaInfo(4288)]       = 1105,     -- Sparktouched Haven/The Oracles
        [C_Map.GetAreaInfo(4291)]       = 1105,     -- Rainspeaker Canopy/The Oracles
        [C_Map.GetAreaInfo(4292)]       = 1104,     -- Frenzyheart Hill/Frenzyheart Tribe
        [C_Map.GetAreaInfo(4297)]       = 1105,     -- Mosswalker Village/The Oracles
        [C_Map.GetAreaInfo(4303)]       = 1104,     -- Hardknuckle Clearing/Frenzyheart Tribe
        [C_Map.GetAreaInfo(4306)]       = 1105,     -- Mistwhisper Village/The Oracles
        [C_Map.GetAreaInfo(4308)]       = 1104,     -- Spearborn Encampment/Frenzyheart Tribe
        [C_Map.GetAreaInfo(4312)]       = 1098,     -- Ebon Watch/Knights of the Ebon Blade
        [C_Map.GetAreaInfo(4369)]       = 47,       -- Dorian's Outpost/Ironforge
        [C_Map.GetAreaInfo(4342)]       = 1098,     -- Acherus: The Ebon Hold (Death Knight start)/Knights of the Ebon Blade
        [C_Map.GetAreaInfo(4392)]       = 1105,     -- The Stormwright's Shelf/The Oracles
        [C_Map.GetAreaInfo(4429)]       = 1085,     -- Grom'arsh Crash-Site/Warsong Offensive
        [C_Map.GetAreaInfo(4418)]       = 21,       -- K3/Booty Bay
        [C_Map.GetAreaInfo(4428)]       = 1126,     -- Frosthold/The Frostborn
        [C_Map.GetAreaInfo(4441)]       = 1064,     -- Camp Tunka'lo/The Taunka
        [C_Map.GetAreaInfo(4442)]       = 1068,     -- Brann's Base-Camp/Explorers' League
        [C_Map.GetAreaInfo(4458)]       = 21,       -- Sparksocket Minefield/Booty Bay
        [C_Map.GetAreaInfo(4459)]       = 21,       -- Ricket's Folly/Booty Bay
        [C_Map.GetAreaInfo(4479)]       = A and 1094 or H and 1124, -- Winter's Breath Lake/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4485)]       = 1126,     -- The Inventor's Library/The Frostborn
        [C_Map.GetAreaInfo(4487)]       = 1085,     -- Frostfloe Deep/Warsong Offensive
        [C_Map.GetAreaInfo(4501)]       = 1106,     -- The Argent Vanguard/Argent Crusade
        [C_Map.GetAreaInfo(4502)]       = 1126,     -- Mimir's Workshop/The Frostborn
        [C_Map.GetAreaInfo(4503)]       = A and 1094 or H and 1124, -- Ironwall Dam/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4504)]       = 1106,     -- Valley of Echoes/Argent Crusade
        [C_Map.GetAreaInfo(4505)]       = 1106,     -- The Breach/Argent Crusade
        [C_Map.GetAreaInfo(4506)]       = 1106,     -- Scourgeholme/Argent Crusade
        [C_Map.GetAreaInfo(4507)]       = A and 1037 or H and 1052, -- The Broken Front/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4511)]       = A and 1037 or H and 1052, -- The Skybreaker/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4512)]       = A and 1037 or H and 1052, -- Orgrim's Hammer/Alliance Vanguard or Horde Expedition
        [C_Map.GetAreaInfo(4516)]       = 1106,     -- Ironwall Rampart/Argent Crusade
        [C_Map.GetAreaInfo(4522)]       = 1156,     -- Icecrown Citadel/The Ashen Verdict
        [C_Map.GetAreaInfo(4536)]       = A and 1068 or H and 1085, -- Frosthowl Cavern/Explorers' League or Warsong Offensive
        [C_Map.GetAreaInfo(4541)]       = 1106,     -- Vanguard Infirmary/Argent Crusade
        [C_Map.GetAreaInfo(4558)]       = A and 1094 or H and 1124, -- Sunreaver's Command/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4559)]       = A and 1094 or H and 1124, -- Windrunner's Overlook/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4580)]       = 1106,     -- Crusaders' Pinnacle/Argent Crusade
        [C_Map.GetAreaInfo(4593)]       = 1106,     -- The Pit of Fiends/Argent Crusade
        [C_Map.GetAreaInfo(4616)]       = A and 1094 or H and 1124, -- Sunreaver's Sanctuary/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4646)]       = A and 1094 or H and 1124, -- Ashwood Lake/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4658)]       = 1106,     -- Argent Tournament Grounds/Argent Crusade
        [C_Map.GetAreaInfo(4666)]       = A and 1094 or H and 1124, -- Sunreaver Pavilion/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4667)]       = A and 1094 or H and 1124, -- Silver Covenant Pavilion/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4669)]       = 1106,     -- The Ring of Champions/Argent Crusade
        [C_Map.GetAreaInfo(4670)]       = 1106,     -- The Aspirants' Ring/Argent Crusade
        [C_Map.GetAreaInfo(4671)]       = 1106,     -- The Argent Valiants' Ring/Argent Crusade
        [C_Map.GetAreaInfo(4672)]       = A and 1094 or H and 1124, -- The Alliance Valiants' Ring/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4673)]       = A and 1094 or H and 1124, -- The Horde Valiants' Ring/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4674)]       = 1106,     -- Argent Pavilion/Argent Crusade
        [C_Map.GetAreaInfo(4676)]       = A and 1094 or H and 1124, -- Sunreaver Pavilion (Outside)/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4677)]       = A and 1094 or H and 1124, -- Silver Covenant Pavilion (Outside)/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4740)]       = A and 1094 or H and 1124, -- The Silver Enclave/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(4760)]       = A and 1094 or H and 1124, -- The Sea Reaver's Run/The Silver Covenant or The Sunreavers
        [C_Map.GetAreaInfo(5561)]       = 1090,     -- The Nexus Entrance/Kirin Tor

        --------- Cataclysm ---------
        [C_Map.GetAreaInfo(3707)]       = 72,       -- Alliance Base/Stormwind
        [C_Map.GetAreaInfo(3708)]       = 76,       -- Horde Encampment/Orgrimmar
        [C_Map.GetAreaInfo(3709)]       = 69,       -- Night Elf Village/Darnassus
        [C_Map.GetAreaInfo(4779)]       = 76,       -- Horde Base Camp/Orgrimmar
        [C_Map.GetAreaInfo(4846)]       = 81,       -- Camp Una'fe/Thunder Bluff
        [C_Map.GetAreaInfo(4851)]       = 81,       -- Ruins of Taurajo/Thunder Bluff
        [C_Map.GetAreaInfo(4856)]       = A and 47 or H and 81, -- Bael Modan/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(4857)]       = 1135,     -- Firestone Point/The Earthen Ring
        [C_Map.GetAreaInfo(4860)]       = 81,       -- Overgrown Camp/Thunder Bluff
        [C_Map.GetAreaInfo(4872)]       = A and 47 or H and 81, -- Bael'dun Keep/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(4912)]       = 76,       -- Warchief's Lookout/Orgrimmar
        [C_Map.GetAreaInfo(4946)]       = A and 47 or H and 81, -- Bael Modan Excavation/Ironforge or Thunder Bluff
        [C_Map.GetAreaInfo(4947)]       = 47,       -- Twinbraid's Patrol/Ironforge
        [C_Map.GetAreaInfo(4948)]       = A and 47 or H and 1133, -- Frazzlecraz Motherlode/Ironforge or Bilgewater Cartel
        [C_Map.GetAreaInfo(4949)]       = 81,       -- Spearhead/Thunder Bluff
        [C_Map.GetAreaInfo(4969)]       = 72,       -- Tranquil Wash/Stormwind
        [C_Map.GetAreaInfo(4970)]       = 76,       -- Legion's Rest/Orgrimmar
        [C_Map.GetAreaInfo(4975)]       = 76,       -- Tenebrous Cavern/Orgrimmar
        [C_Map.GetAreaInfo(4976)]       = 72,       -- Darkbreak Cove/Stormwind
        [C_Map.GetAreaInfo(4986)]       = 81,       -- Vendetta Point/Thunder Bluff
        [C_Map.GetAreaInfo(5050)]       = 1204,     -- Firelands Hatchery (The Hatchery)/Avengers of Hyjal
        [C_Map.GetAreaInfo(5064)]       = 1204,     -- Firelands Forgeworks (The Anvil of Flame)/Avengers of Hyjal
        [C_Map.GetAreaInfo(5067)]       = 1204,     -- The Inner Spire/Avengers of Hyjal
        [C_Map.GetAreaInfo(5099)]       = 1204,     -- The Crucible of Flame (The Crucible)/Avengers of Hyjal
        [C_Map.GetAreaInfo(5137)]       = 1133,     -- The Krazzworks/Bilgewater Cartel
        [C_Map.GetAreaInfo(5140)]       = A and 72 or H and 1133, -- Highbank/Stormwind or Bilgewater Cartel
        [C_Map.GetAreaInfo(5155)]       = 1091,     -- Vermillion Redoubt/The Wyrmrest Accord
        [C_Map.GetAreaInfo(5248)]       = 72,       -- Voldrin's Hold/Stormwind
        [C_Map.GetAreaInfo(5249)]       = 76,       -- Stygian Bounty/Orgrimmar
        [C_Map.GetAreaInfo(5293)]       = 1171,     -- Crumbling Depths/Therazane
        [C_Map.GetAreaInfo(5294)]       = 1171,     -- Shuddering Spires/Therazane
        [C_Map.GetAreaInfo(5295)]       = 1171,     -- The Pale Roost/Therazane
        [C_Map.GetAreaInfo(5296)]       = 1171,     -- Therazane's Throne/Therazane
        [C_Map.GetAreaInfo(5297)]       = 1171,     -- Halcyon Egress/Therazane
        [C_Map.GetAreaInfo(5298)]       = 1171,     -- Twilight Precipice/Therazane
        [C_Map.GetAreaInfo(5299)]       = 1171,     -- Lorthuna's Gate/Therazane
        [C_Map.GetAreaInfo(5300)]       = 1171,     -- Verlok Stand/Therazane
        [C_Map.GetAreaInfo(5302)]       = 1171,     -- Crimson Expanse/Therazane
        [C_Map.GetAreaInfo(5338)]       = 1171,     -- Fungal Deep/Therazane
        [C_Map.GetAreaInfo(5408)]       = 1068,     -- Explorer's League Digsite/Explorer's League
        [C_Map.GetAreaInfo(5437)]       = 1135,     -- Ring of the Elements/The Earthen Ring
        [C_Map.GetAreaInfo(5438)]       = 1135,     -- The Maw of Madness/The Earthen Ring
        [C_Map.GetAreaInfo(5439)]       = 1135,     -- Ruins of Drakgor/The Earthen Ring
        [C_Map.GetAreaInfo(5461)]       = A and 72 or H and 1133, -- Dragonmaw Pass/Stormwind or Bilgewater Cartel
        [C_Map.GetAreaInfo(5462)]       = A and 72 or H and 1133, -- Wyrms' Bend/Stormwind or Bilgewater Cartel
        [C_Map.GetAreaInfo(5470)]       = A and 72 or H and 1133, -- Victor's Point/Stormwind or Bilgewater Cartel
        [C_Map.GetAreaInfo(5595)]       = 1091,     -- Obsidian Forest/The Wyrmrest Accord
        [C_Map.GetAreaInfo(5660)]       = 1091,     -- Obsidian Lair/The Wyrmrest Accord
        [C_Map.GetAreaInfo(5664)]       = 1135,     -- Iso'rath/The Earthen Ring
    }
    return subZonesAndFactions
end